Attribute VB_Name = "SBIGTypes"
'
'   Basic Type Defines for Structs defined
'   in PARDRV.H
'
'   Ref:PARDRV.H Ver 3.3
'   Created 4-18-2001 - SBIG
'

'
' Command Constants
'
Public Enum PAR_COMMAND
    ' 1-10
    CC_START_EXPOSURE = 1
    CC_END_EXPOSURE
    CC_READOUT_LINE
    CC_DUMP_LINES
    CC_SET_TEMPERATURE_REGULATION
    CC_QUERY_TEMPERATURE_STATUS
    CC_ACTIVATE_RELAY
    CC_PULSE_OUT
    CC_ESTABLISH_LINK
    CC_GET_DRIVER_INFO
    

    ' 11 - 20
    CC_GET_CCD_INFO
    CC_QUERY_COMMAND_STATUS
    CC_MISCELLANEOUS_CONTROL
    CC_READ_SUBTRACT_LINE
    CC_UPDATE_CLOCK
    CC_READ_OFFSET
    CC_OPEN_DRIVER
    CC_CLOSE_DRIVER
    CC_TX_SERIAL_BYTES
    CC_GET_SERIAL_STATUS

    ' 21 - 30
    CC_AO_TIP_TILT
    CC_AO_SET_FOCUS
    CC_AO_DELAY
    CC_GET_TURBO_STATUS
    CC_END_READOUT
    CC_GET_US_TIMER
    CC_OPEN_DEVICE
    CC_CLOSE_DEVICE
    CC_SET_IRQL
    CC_GET_IRQL

    ' 31 - 40
    CC_GET_LINE
    CC_GET_LINK_STATUS
    CC_GET_DRIVER_HANDLE
    CC_SET_DRIVER_HANDLE

    '
    ' SBIG Use Only Commands
    '
    CC_SEND_BLOCK = 90
    CC_SEND_BYTE
    CC_GET_BYTE
    CC_SEND_AD
    CC_GET_AD
    CC_CLOCK_AD
    CC_LAST_COMMAND
End Enum

'
' Error Codes
'
Global Const CE_ERROR_BASE = 1
Public Enum PAR_ERROR
    CE_NO_ERROR = 0
    CE_CAMERA_NOT_FOUND = CE_ERROR_BASE
    CE_EXPOSURE_IN_PROGRESS
    CE_NO_EXPOSURE_IN_PROGRESS
    CE_UNKNOWN_COMMAND
    CE_BAD_CAMERA_COMMAND
    CE_BAD_PARAMETER
    CE_TX_TIMEOUT
    CE_RX_TIMEOUT
    CE_NAK_RECEIVED
    CE_CAN_RECEIVED

    ' 11 - 20
    CE_UNKNOWN_RESPONSE
    CE_BAD_LENGTH
    CE_AD_TIMEOUT
    CE_KBD_ESC
    CE_CHECKSUM_ERROR
    CE_EEPROM_ERROR
    CE_SHUTTER_ERROR
    CE_UNKNOWN_CAMERA
    CE_DRIVER_NOT_FOUND
    CE_DRIVER_NOT_OPEN

    ' 21 - 30 */
    CE_DRIVER_NOT_CLOSED
    CE_SHARE_ERROR
    CE_TCE_NOT_FOUND
    CE_AO_ERROR
    CE_ECP_ERROR
    CE_MEMORY_ERROR
    CE_NEXT_ERROR
End Enum

'
' General Enums/Constants
'
Public Enum PAR_COMMAND_STATUS
    CS_IDLE
    CS_IN_PROGRESS
    CS_INTEGRATING
    CS_INTEGRATION_COMPLETE
End Enum
Global Const CS_PULSE_IN_ACTIVE = &H8000
Global Const CS_WAITING_FOR_TRIGGER = &H8000

'
'    ABG_STATE7 - Passed to Start Exposure Command
'    MY_LOGICAL - General purpose type
'    DRIVER_REQUEST - Used with Get Driver Info command
'    CCD_REQUEST - Used with Imaging commands to specify CCD
'    CCD_INFO_REQUEST - Used with Get CCD Info Command
'    PORT - Used with Establish Link Command
'    CAMERA_TYPE - Returned by Establish Link and Get CCD Info commands
'    SHUTTER_COMMAND, SHUTTER_STATE7 - Used with Start Exposure
'        and Miscellaneous Control Commands
'    TEMPERATURE_REGULATION - Used with Enable Temperature Regulation
'    LED_STATE - Used with the Miscellaneous Control Command
'    FILTER_COMMAND, FILTER_STATE - Used with the Miscellaneous
'        Control command
'    AD_SIZE, FILTER_TYPE - Used with the GetCCDInfo3 Command
'    AO_FOCUS_COMMAND - Used with the AO Set Focus Command
'    LPT_PORT - Used with Open Device command
'
Public Enum ABG_STATE7
    ABG_LOW7
    ABG_CLK_LOW7
    ABG_CLK_MED7
    ABG_CLK_HI7
End Enum
Public Enum DRIVER_REQUEST
    DRIVER_STD
    DRIVER_EXTENDED
End Enum
Public Enum CCD_REQUEST
    CCD_IMAGING
    CCD_TRACKING
End Enum
Public Enum CCD_INFO_REQUEST
    CCD_INFO_IMAGING
    CCD_INFO_TRACKING
    CCD_INFO_EXTENDED
    CCD_INFO_EXTENDED_5C
End Enum
Public Enum IMAGING_ABG
    ABG_NOT_PRESENT
    ABG_PRESENT
End Enum
Public Enum port
    BASE_ADDR
    PORT0
    PORT1
    PORT2
End Enum
Public Enum PORT_RATE
    BR_AUTO
    BR_9600
    BR_19K
    BR_38K
    BR_57K
    BR_115K
End Enum
Public Enum CAMERA_TYPE
    ST7_CAMERA = 4
    ST8_CAMERA
    ST5C_CAMERA
    TCE_CONTROLLER
    ST237_CAMERA
    STK_CAMERA
    ST9_CAMERA
    STV_CAMERA
    ST10_CAMERA
    ST1K_CAMERA
End Enum
Public Enum SHUTTER_COMMAND
    SC_LEAVE_SHUTTER
    SC_OPEN_SHUTTER
    SC_CLOSE_SHUTTER
    SC_INITIALIZE_SHUTTER
End Enum
Public Enum SHUTTER_STATE7
    SS_OPEN
    SS_CLOSED
    SS_OPENING
    SS_CLOSING
End Enum
Public Enum TEMPERATURE_REGULATION
    REGULATION_OFF
    REGULATION_ON
    REGULATION_OVERRIDE
    REGULATION_FREEZE
    REGULATION_UNFREEZE
    REGULATION_ENABLE_AUTOFREEZE
    REGULATION_DISABLE_AUTOFREEZE
End Enum
Global Const REGULATION_FROZEN_MASK = &H8000
Public Enum LED_STATE
    LED_OFF
    LED_ON
    LED_BLINK_LOW
    LED_BLINK_HIGH
End Enum
Public Enum FILTER_COMMAND
    FILTER_LEAVE
    FILTER_SET_1
    FILTER_SET_2
    FILTER_SET_3
    FILTER_SET_4
    FILTER_SET_5
    FILTER_STOP
    FILTER_INIT
End Enum
Public Enum FILTER_STATE
    FS_MOVING
    FS_AT_1
    FS_AT_2
    FS_AT_3
    FS_AT_4
    FS_AT_5
    FS_UNKNOWN
End Enum
Public Enum AD_SIZE
    AD_UNKNOWN
    AD_12_BITS
    AD_16_BITS
End Enum
Public Enum FILTER_TYPE
    FW_UNKNOWN
    FW_EXTERNAL
    FW_VANE
    FW_FILTER_WHEEL
End Enum
Public Enum AO_FOCUS_COMMAND
    AOF_HARD_CENTER
    AOF_SOFT_CENTER
    AOF_STEP_IN
    AOF_STEP_OUT
End Enum
Public Enum LPT_PORT
    LPT_1 = 1
    LPT_2
    LPT_3
End Enum

'
'    General Purpose Flags
'
Global Const END_SKIP_DELAY = &H8000    'set in ccd parameter of EndExposure
                                        'command to skip synchronization
                                        'delay - Use this to increase the
                                        'rep rate when taking darks to later
                                        'be subtracted from SC_LEAVE_SHUTTER
                                        'exposures such as when tracking and
                                        'imaging
Global Const EXP_WAIT_FOR_TRIGGER_IN = &H80000000   'set in exposureTime to wait
                                                    'for trigger in pulse
Global Const EXP_SEND_TRIGGER_OUT = &H40000000      'set in exposureTime to send
                                                    'trigger out Y-
Global Const EXP_LIGHT_CLEAR = &H20000000           'set to do light clear of the
                                                    'CCD (Kaiser only)
Global Const EXP_TIME_MASK = &HFFFFFF               'mask with exposure time to
                                                    'remove flags
Global Const MIN_ST7_EXPOSURE = 11      'Minimum exposure is 11/100ths second

'
' Basic Types for C structs
'
Type StartExposureParams
    ccd As Integer
    expLowByte As Byte         'treat long as 4 bytes
    expMidLowByte As Byte      'so Basic keeps byte
    expMidHighByte As Byte     'struct align as required
    expHighByte As Byte        'by driver
    abgState As Integer
    openShutter As Integer
End Type
Type EndExposureParams
    ccd As Integer
End Type
Type ReadoutLineParams
   ccd As Integer
   readoutMode As Integer
   pixelStart As Integer
   pixelLength As Integer
End Type
Type GetLineParams
    ccd As Integer
    readoutMode As Integer
    pixelStart As Integer
    pixelLength As Integer
End Type
Type DumpLinesParams
   ccd As Integer
   readoutMode As Integer
   lineLength As Integer
End Type
Type EndReadoutParams
    ccd As Integer
End Type
Type SetTemperatureRegulationParams
    regulation As Integer
    ccdSetpoint As Integer
End Type
Type QueryTemperatureStatusResults
    enabled As Boolean
    ccdSetpoint As Integer
    power As Integer
    ccdThermistor As Integer
    ambientThermistor As Integer
End Type
Type ActivateRelayParams
    tXPlus As Integer
    tXMinus As Integer
    tYPlus As Integer
    tYMinus As Integer
End Type
Type PulseOutParams
    numberPulses As Integer
    pulseWidth As Integer
    pulsePeriod As Integer
End Type
Type TXSerialBytesParams
    dataLength As Integer
    data(0 To 255) As Byte
End Type
Type TXSerialBytesResults
    bytesSent As Integer
End Type
Type GetSerialStatusResults
    clearToCOM As Boolean
End Type
Type EstablishLinkParams
    port As Integer
    baseAddress As Integer
End Type
Type EstablishLinkResults
    cameraType As Integer
End Type
Type GetDriverInfoParams
    request As Integer
End Type
Type GetDriverInfoResults0
    version As Integer
    name As String * 64
    maxRequest As Integer
End Type
Type GetCCDInfoParams
    request As Integer
End Type
Type readoutInfo
    mode As Integer
    width As Integer
    height As Integer
    gain As Integer
    pixelWidthLow As Byte       'declare as byte for struct align
    pixelWidthMidLow As Byte
    pixelWidthMidHi As Byte
    pixelWidthHi As Byte
    pixelHeightLow As Byte       'declare as byte for struct align
    pixelHeightMidLow As Byte
    pixelHeightMidHi As Byte
    pixelHeightHi As Byte
End Type
Type GetCCDInfoResults0
    firmwareVersion As Integer
    cameraType As Integer
    name As String * 64
    readoutModes As Integer
    readoutInfo(0 To 19) As readoutInfo
End Type
Type GetCCDInfoResults2
    badColumns As Integer
    columns(0 To 3) As Integer
    imagingABG As Integer
    serialNumber As String * 10
End Type
Type GetCCDInfoResults3
    adSize As Integer
    filterType As Integer
End Type
Type QueryCommandStatusParams
    command As Integer
End Type
Type QueryCommandStatusResults
    status As Integer
End Type
Type MiscellaneousControlParams
    shutterCommand As Integer
    ledState As Integer
End Type
Type ReadOffsetParams
    ccd As Integer
End Type
Type ReadOffsetResults
    offset As Integer
End Type
Type AOTipTiltParams
    xDeflection As Integer
    yDeflection As Integer
End Type
Type AOSetFocusParams
    focusCommand As Integer
End Type
Type AODelayParams
    delayLow As Byte        'declare as byte for struct align
    delayMidLow As Byte
    delayMidHi As Byte
    delayHi As Byte
End Type
Type GetTurboStatusResults
    turboDetected As Integer
End Type
Type OpenDeviceParams
    port As Integer         '1 for lpt1, 2 for lpt2, etc
End Type
Type SetIRQLParams
    level As Integer
End Type
Type GetIRQLParams
    level As Integer
End Type
Type GetLinkStatusResults
    linkEstablished As Integer
    baseAddress As Integer
    cameraType As Integer
    comTotalLow As Byte        'declare as byte for struct align
    comTotalMidLow As Byte
    comTotalMidHi As Byte
    comTotalHi As Byte
    comFailedLow As Byte        'declare as byte for struct align
    comFailedMidLow As Byte
    comFailedMidHi As Byte
    comFailedHi As Byte
End Type
Type GetUSTimerResults
    countLow As Byte        'declare as byte for struct align
    countMidLow As Byte
    countMidHi As Byte
    countHi As Byte
End Type
Type SendBlockParams
    port As Integer
    length As Integer
    sourcePtrLow As Byte        'declare as byte for struct align
    sourcePtrMidLow As Byte
    sourcePtrMidHi As Byte
    sourcePtrHi As Byte
End Type
Type SendByteParams
    port As Integer
    data As Integer
End Type
Type ClockADParams
    ccd As Integer
    readoutMode As Integer
    pixelStart As Integer
    pixelLength As Integer
End Type
Type SendSTVBlockParams
    outLength As Integer
    outPtrLow As Byte        'declare as byte for struct align
    outPtrMidLow As Byte
    outPtrMidHi As Byte
    outPtrHi As Byte
    inLength As Integer
    inPtrLow As Byte        'declare as byte for struct align
    inPtrMidLow As Byte
    inPtrMidHi As Byte
    inPtrHi As Byte
End Type

'
' External Driver Function Declaration
'
Declare Function ParDrvCommandVB Lib "sbigvb32.dll" (ByVal command As Integer, ByRef params As Any, ByRef results As Any) As Integer

